
********************************************************************************
* 1. Farm chart: Total emp and ests, shale vs boom vs control
********************************************************************************

use "../data/intermediate data/farms",clear
keep if inlist(region_id,1,3,4,7) | control==1 // Limit to control group choice set, and posgroup (Ana, Bak,EF,Perm)

rename emp ctyemp 
rename farms ctyest 

keep year fips shale ctyemp ctyest

collapse (mean) ctyemp ctyest,by(year shale)
rename ctyemp emp
rename ctyest est

gen emp2007_t=emp if year==2007
gen est2007_t=est if year==2007

bys shale: egen emp2007=mean(emp2007_t)
bys shale: egen est2007=mean(est2007_t)

replace emp=100*emp/emp2007
replace est=100*est/est2007

keep year shale emp est

reshape wide emp est,i(year) j(shale)

preserve
	use "../data/intermediate data/farms",clear
	keep if region_id!=0

	rename emp ctyemp 
	rename farms ctyest 


	keep year fips ctyemp ctyest
	
	collapse (mean) ctyemp ctyest,by(year)
	rename ctyemp empshale
	rename ctyest estshale
	
	gen emp2007_t=empshale if year==2007
	gen est2007_t=estshale if year==2007
	
	egen emp2007=mean(emp2007_t)
	egen est2007=mean(est2007_t)
	
	replace empshale=100*empshale/emp2007
	replace estshale=100*estshale/est2007
	
	keep year empshale estshale
	
	tempfile shale
	save `shale',replace
restore

sort year
merge 1:1 year using `shale'



graph twoway /*
*/(connected empshale year,lwidth(thick) lpattern(longdash) lcolor(orange) msymbol(i))/*
*/(connected emp1 year,lwidth(thick) lpattern(dash) lcolor(blue) msymbol(i))/*
*/(connected emp0 year,lwidth(thick) lcolor(black) msymbol(i)),/*
*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white) lstyle(none) ilstyle(none))/*
*/plotregion(color(white) icolor(white) fcolor(white) ifcolor(white) lstyle(none))/*
*/xtitle("") xlabel(2002(5)2017,angle(45) labsize(4.5))/*
*/ylabel(,angle(horizontal) nogrid labsize(4.5)) ytitle("Percent of 2006 level",size(4.5))/*
*/legend(label(1 "Shale counties") label(2 "Boom towns") label(3 "Non-shale control superset") region(lcolor(white)) position(7) ring(0) cols(1) size(4.5) symxsize(6) keygap(1) rowgap(1))/*
*/subtitle("Hired labor",size(4.5) justification(left) margin(b+1 t) bexpand) ysize(2.5) xsize(3.25)
graph save empcount,replace
label variable empshale "Shale counties"
label variable emp1 "Boom towns"
label variable emp0 "Non-shale control set"


graph twoway /*
*/(connected estshale year,lwidth(thick) lpattern(longdash) lcolor(orange) msymbol(i))/*
*/(connected est1 year,lwidth(thick) lpattern(dash) lcolor(blue) msymbol(i))/*
*/(connected est0 year,lwidth(thick) lcolor(black) msymbol(i)),/*
*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white) lstyle(none) ilstyle(none))/*
*/plotregion(color(white) icolor(white) fcolor(white) ifcolor(white) lstyle(none))/*
*/xtitle("") xlabel(2002(5)2017,angle(45) labsize(4.5))/*
*/ylabel(,angle(horizontal) nogrid labsize(4.5)) ytitle("Percent of 2006 level",size(4.5))/*
legend(label(1 "Shale counties") label(2 "Non-shale counties") region(lcolor(white)) position(11) ring(0) cols(1) size(medlarge) symxsize(4) keygap(1) rowgap(1))
*/legend(off)/*
*/subtitle("Farms",size(4.5) justification(left) margin(b+1 t) bexpand) ysize(2.5) xsize(3.25)
graph save estcount,replace
label variable estshale "Shale counties"
label variable est1 "Boom towns"
label variable est0 "Non-shale control set"



graph combine empcount.gph estcount.gph, iscale(1)/*
subtitle("Economic activity excluding oil & gas mining, shale vs. non-shale counties",justification(left) margin(b+1 t) bexpand size(large)) 
*/graphregion(color(white) margin(tiny))/*
*/note("Note: Average county-level hired worker and farm counts scaled by 2007 averages."/*
*/"Boom towns are Anadarko, Bakken, Eagle Ford, and Permian Basin."/*
*/"Source: Census of Agriculture. NAICS 111 and 112. States that include or border shale counties omitted.",size(4.5))/*
*/xsize(6.5) ysize(3)
graph export ../output/farms_posgroup_allcounts.pdf,replace




********************************************************************************
* 2. Non-farm agriculture
********************************************************************************

use "../data/intermediate data/cbp_panel",clear
keep if inlist(region_id,1,3,4,7) | control==1 // Limit to control group choice set, and posgroup (Ana, Bak,EF,Perm)

keep if naics=="11----"


collapse (mean) emp est,by(year shale)

gen emp2006_t=emp if year==2006
gen est2006_t=est if year==2006

bys shale: egen emp2006=mean(emp2006_t)
bys shale: egen est2006=mean(est2006_t)

replace emp=100*emp/emp2006
replace est=100*est/est2006

keep year shale emp est

reshape wide emp est,i(year) j(shale)

preserve
	use "../data/intermediate data/cbp_panel",clear
	keep if region_id!=0
	keep if naics=="11----"
	
	collapse (mean) emp est,by(year shale)
	rename emp empshale 
	rename est estshale 
	
	gen emp2006_t=empshale if year==2006
	gen est2006_t=estshale if year==2006
	
	egen emp2006=mean(emp2006_t)
	egen est2006=mean(est2006_t)
	
	replace empshale=100*empshale/emp2006
	replace estshale=100*estshale/est2006
	
	keep year empshale estshale
	
	tempfile shale
	save `shale',replace
restore

sort year
merge 1:1 year using `shale'


graph twoway /*
*/(connected empshale year,lwidth(thick) lpattern(longdash) lcolor(orange) msymbol(i))/*
*/(connected emp1 year,lwidth(thick) lpattern(dash) lcolor(blue) msymbol(i))/*
*/(connected emp0 year,lwidth(thick) lcolor(black) msymbol(i)),/*
*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white) lstyle(none) ilstyle(none))/*
*/plotregion(color(white) icolor(white) fcolor(white) ifcolor(white) lstyle(none))/*
*/xtitle("") xlabel(2000(2)2014,angle(45) labsize(4.5))/*
*/ylabel(,angle(horizontal) nogrid labsize(4.5)) ytitle("Percent of 2006 level",size(4.5))/*
*/legend(label(1 "Shale counties") label(2 "Boom towns") label(3 "Non-shale control set") region(lcolor(white)) position(7) ring(0) cols(1) size(4.5) symxsize(6) keygap(1) rowgap(1))/*
*/subtitle("Employment",size(4.5) justification(left) margin(b+1 t) bexpand) ysize(2.5) xsize(3.25)
graph save empcount,replace
label variable empshale "Shale counties"
label variable emp1 "Boom towns"
label variable emp0 "Non-shale control set"


graph twoway /*
*/(connected estshale year,lwidth(thick) lpattern(longdash) lcolor(orange) msymbol(i))/*
*/(connected est1 year,lwidth(thick) lpattern(dash) lcolor(blue) msymbol(i))/*
*/(connected est0 year,lwidth(thick) lcolor(black) msymbol(i)),/*
*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white) lstyle(none) ilstyle(none))/*
*/plotregion(color(white) icolor(white) fcolor(white) ifcolor(white) lstyle(none))/*
*/xtitle("") xlabel(2000(2)2014,angle(45) labsize(4.5))/*
*/ylabel(,angle(horizontal) nogrid labsize(4.5)) ytitle("Percent of 2006 level",size(4.5))/*
legend(label(1 "Shale counties") label(2 "Non-shale counties") region(lcolor(white)) position(11) ring(0) cols(1) size(medlarge) symxsize(4) keygap(1) rowgap(1))
*/legend(off)/*
*/subtitle("Establishments",size(4.5) justification(left) margin(b+1 t) bexpand) ysize(2.5) xsize(3.25)
graph save estcount,replace
label variable estshale "Shale counties"
label variable est1 "Boom towns"
label variable est0 "Non-shale control set"



graph combine empcount.gph estcount.gph, iscale(1)/*
subtitle("Oil and gas mining activity, shale vs. non-shale counties",justification(left) margin(b+1 t) bexpand size(large))
*/ graphregion(color(white) margin(tiny))/*
*/note("Note: Average county-level employment and establishment counts scaled by 2006 averages."/*
*/"Boom towns are Anadarko, Bakken, Eagle Ford, and Permian Basin."/*
*/"Source: County Business Patterns. NAICS 11 excl. 111 & 112. States that include or border shale counties omitted.",size(4.5))/*
*/xsize(6.5) ysize(3)
graph export ../output/cbp_posgroup_nonfarmag.pdf,replace
